@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python3
 import requests
 import os
 import logging
@@ -10,6 +10,8 @@ from pydub.playback import play
 from datetime import datetime
 from notifypy import Notify
 import shelve
+from importlib import import_module
+import version
 
 os.environ.setdefault('DISPLAY', ':0.0')
 
@@ -21,6 +23,7 @@ def get_arguments():
                          FROM (covishild, covaxin, sputnik)")
     parser.add_argument('music', help="Path of Music or Song file. Play when vaccination center detected")
     parser.add_argument('-l', '--log', help="Log File to Store Logs (Default siren_log.log file in current directory")
+    parser.add_argument('--version', action='version',version=version.__version__)
     return parser.parse_args()
 
 def api_call(pincode):
@@ -65,7 +68,7 @@ def check_available_slot(response_dict, selected_dates = [],
     return is_available
 
 def _check_and_update_cache(session, center):
-    vdb = shelve.open("/tmp/vaccinedb.db", writeback=True)
+    vdb = shelve.open("vaccinedb.db", writeback=True)
     key = str(center["center_id"])+","+session["session_id"]
     current_ts = int(time.time())
     try:
@@ -73,8 +76,8 @@ def _check_and_update_cache(session, center):
             if vdb[key]["available_capacity"] <  session["available_capacity"]:
                 vdb[key]["available_capacity"] =  session["available_capacity"]
                 vdb[key]["timestamp"] = current_ts
-                logging.info("For {0}, {1}, {2} : Vaccine Slots Incremented ".format(session["date"],
-                                    center["address"], center["pincode"]))
+                logging.info("For {0}, {1} : Vaccine Slots Incremented ".format(session["date"],
+                                    center["address"]))
                 return True
             elif (vdb[key]["available_capacity"] ==  session["available_capacity"]) and (current_ts - vdb[key]["timestamp"]) > 300:
                 vdb[key]["timestamp"] = current_ts
@@ -82,8 +85,8 @@ def _check_and_update_cache(session, center):
             elif (vdb[key]["available_capacity"] >  session["available_capacity"]) and (current_ts - vdb[key]["timestamp"]) > 300:
                 vdb[key]["available_capacity"] = session["available_capacity"]
                 vdb[key]["timestamp"] = current_ts
-                logging.info("For {0}, {1}, {2} : Vaccine Slots Decreased".format(session["date"],
-                                    center["address"], center["pincode"]))
+                logging.info("For {0}, {1} : Vaccine Slots Decreased".format(session["date"],
+                                    center["address"]))
                 return True
             elif vdb[key]["available_capacity"] == 0:
                 del vdb[key]
@@ -143,7 +146,6 @@ def main():
             play_siren(args.music)
         else:
             logging.info("No New Vaccination Center Detected!")
-
     else:
         print("Pincode Not Entered!")
 if __name__ == '__main__':
